@@ -32,7 +32,10 @@ class BorgCreateThread(BorgThread):
                 repo.total_unique_chunks = stats['total_unique_chunks']
                 repo.save()
 
-            self.app.backup_progress_event.emit(self.tr('Backup finished.'))
+            if result['returncode'] == 1:
+                self.app.backup_progress_event.emit(self.tr('Backup finished with warnings. See logs for details.'))
+            else:
+                self.app.backup_progress_event.emit(self.tr('Backup finished.'))
 
     def progress_event(self, fmt):
         self.app.backup_progress_event.emit(fmt)
@@ -43,6 +46,7 @@ class BorgCreateThread(BorgThread):
 
     def finished_event(self, result):
         self.app.backup_finished_event.emit(result)
+        self.result.emit(result)
         self.pre_post_backup_cmd(self.params, cmd='post_backup_cmd', returncode=result['returncode'])
 
     @classmethod
@@ -94,7 +98,8 @@ class BorgCreateThread(BorgThread):
                 ret['message'] = trans_late('messages', 'Current Wifi is not allowed.')
                 return ret
 
-        if profile.dont_run_on_metered_networks and network_status_monitor.is_network_metered():
+        if profile.repo.is_remote_repo() and profile.dont_run_on_metered_networks \
+                and network_status_monitor.is_network_metered():
             ret['message'] = trans_late('messages', 'Not running backup over metered connection.')
             return ret
 
@@ -127,6 +132,9 @@ class BorgCreateThread(BorgThread):
             profile.compression,
         ]
 
+        if profile.repo.create_backup_cmd:
+            cmd.extend(profile.repo.create_backup_cmd.split(' '))
+
         # Add excludes
         # Partly inspired by borgmatic/borgmatic/borg/create.py
         if profile.exclude_patterns is not None:
