@@ -636,27 +636,27 @@
     <message>
         <location filename="../../assets/UI/exportwindow.ui" line="23"/>
         <source>If set, sharing this file with others will disclose your borg passphrase. Use with caution!</source>
-        <translation type="unfinished"/>
+        <translation>Se se define, compartir este ficheiro con outras persoas revelará a súa frase de paso. Úseo con precaución!</translation>
     </message>
     <message>
         <location filename="../../assets/UI/exportwindow.ui" line="26"/>
         <source>Include borg passphrase in export</source>
-        <translation type="unfinished"/>
+        <translation>Incluír a frase de paso borg na exportación</translation>
     </message>
     <message>
         <location filename="../../assets/UI/importwindow.ui" line="25"/>
         <source>Borg passphrase:</source>
-        <translation type="unfinished"/>
+        <translation>Frase de paso de Borg:</translation>
     </message>
     <message>
         <location filename="../../assets/UI/importwindow.ui" line="53"/>
         <source>Overwrite existing profile</source>
-        <translation type="unfinished"/>
+        <translation>Sobrescribe o perfil existente</translation>
     </message>
     <message>
         <location filename="../../assets/UI/importwindow.ui" line="60"/>
         <source>Overwrite existing settings</source>
-        <translation type="unfinished"/>
+        <translation>Sobrescribe os axustes existentes</translation>
     </message>
 </context>
 <context>
@@ -690,37 +690,37 @@
     <message>
         <location filename="../../views/export_window.py" line="29"/>
         <source>Export Profile</source>
-        <translation type="unfinished"/>
+        <translation>Exportar o perfil</translation>
     </message>
     <message>
         <location filename="../../views/export_window.py" line="38"/>
         <source>The current profile_export has no password</source>
-        <translation type="unfinished"/>
+        <translation>O profile_export actual non ten contrasinal</translation>
     </message>
     <message>
         <location filename="../../views/export_window.py" line="43"/>
         <source>Save profile_export</source>
-        <translation type="unfinished"/>
+        <translation>Gardar profile_export</translation>
     </message>
     <message>
         <location filename="../../views/export_window.py" line="55"/>
         <source>Error while exporting</source>
-        <translation type="unfinished"/>
+        <translation>Produciuse un erro ao exportar</translation>
     </message>
     <message>
         <location filename="../../views/export_window.py" line="71"/>
         <source>The file {} could not be created. Please choose another location.</source>
-        <translation type="unfinished"/>
+        <translation>Non foi posíbel crear o ficheiro {}. Escolla outra localización.</translation>
     </message>
     <message>
         <location filename="../../views/export_window.py" line="78"/>
         <source>Profile export successful!</source>
-        <translation type="unfinished"/>
+        <translation>A exportación do perfil foi satisfactoria.</translation>
     </message>
     <message>
         <location filename="../../views/export_window.py" line="78"/>
         <source>Profile export written to {}.</source>
-        <translation type="unfinished"/>
+        <translation>A exportación do perfil foi escrita en {}.</translation>
     </message>
 </context>
 <context>
@@ -1191,55 +1191,57 @@
     <message>
         <location filename="../../views/import_window.py" line="24"/>
         <source>Import Profile</source>
-        <translation type="unfinished"/>
+        <translation>Importar o perfil</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="32"/>
         <source>The passphrase has been loaded from the export file</source>
-        <translation type="unfinished"/>
+        <translation>A frase de paso foi cargada dende o ficheiro de exportación</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="39"/>
         <source>The passphrase has been loaded from your keyring</source>
-        <translation type="unfinished"/>
+        <translation>A frase de paso foi cargada dende o seu chaveiro</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="49"/>
         <source>A profile with the name {} does not exist. Nothing to overwrite.</source>
-        <translation type="unfinished"/>
+        <translation>Non existe un perfil co nome {}. Nada que sobreescribir.</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="60"/>
         <source>Error while importing</source>
-        <translation type="unfinished"/>
+        <translation>Produciuse un erro ao importar</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="76"/>
         <source>Schema upgrade failure, file a bug report with the link in the Misc tab with the following error: 
  {0} 
  {1}</source>
-        <translation type="unfinished"/>
+        <translation>Produciuse u fallo na actualización do esquema, presenta un informe de erro coa ligazón na lapela Varios co seguinte erro:
+{0} 
+{1}</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="79"/>
         <source>Newer profile_export export files cannot be used on older versions.</source>
-        <translation type="unfinished"/>
+        <translation>Non é posíbel empregar ficheiros de exportación profile_export recentes en versións anteriores.</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="81"/>
         <source>Cannot read profile_export export file due to permission error.</source>
-        <translation type="unfinished"/>
+        <translation>Non é posíbel ler o ficheiro de exportación profile_export por mor dun erro de permisos.</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="83"/>
         <source>Profile export file not found.</source>
-        <translation type="unfinished"/>
+        <translation>Non se atopou o ficheiro de exportación do perfil.</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../../views/main_window.py" line="255"/>
+        <location filename="../../views/main_window.py" line="256"/>
         <source>Task cancelled</source>
         <translation>Tarefa cancelada</translation>
     </message>
@@ -1324,63 +1326,58 @@
         <translation>Confirmar a eliminación</translation>
     </message>
     <message>
-        <location filename="../../views/main_window.py" line="272"/>
+        <location filename="../../views/main_window.py" line="273"/>
         <source>Should Vorta continue to run in the background?</source>
         <translation>Debería seguir executandose Vorta nun segundo plano?</translation>
     </message>
     <message>
-        <location filename="../../views/main_window.py" line="277"/>
+        <location filename="../../views/main_window.py" line="278"/>
         <source>Quit</source>
         <translation>Saír</translation>
     </message>
     <message>
-        <location filename="../../views/main_window.py" line="278"/>
+        <location filename="../../views/main_window.py" line="279"/>
         <source>Don&apos;t show this again</source>
         <translation>Non volver amosar isto</translation>
     </message>
     <message>
         <location filename="../../views/main_window.py" line="84"/>
         <source>Import from file...</source>
-        <translation type="unfinished"/>
+        <translation>Importar dende un ficheiro…</translation>
     </message>
     <message>
         <location filename="../../views/main_window.py" line="177"/>
         <source>Can&apos;t delete the last profile.</source>
-        <translation type="unfinished"/>
+        <translation>Non é posíbel eliminar o último perfil.</translation>
     </message>
     <message>
         <location filename="../../views/main_window.py" line="205"/>
         <source>Profile import successful!</source>
-        <translation type="unfinished"/>
+        <translation>A importación do perfil foi satisfactoria.</translation>
     </message>
     <message>
         <location filename="../../views/main_window.py" line="205"/>
         <source>Profile {} imported.</source>
-        <translation type="unfinished"/>
+        <translation>O perfil {} foi importado.</translation>
     </message>
     <message>
         <location filename="../../views/main_window.py" line="214"/>
         <source>Load profile</source>
-        <translation type="unfinished"/>
+        <translation>Cargar o perfil</translation>
     </message>
     <message>
         <location filename="../../views/main_window.py" line="214"/>
         <source>JSON (*.json);;All files (*)</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../../views/main_window.py" line="222"/>
-        <source>Error</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../../views/main_window.py" line="222"/>
-        <source>This file does not contain valid JSON.</source>
-        <translation type="unfinished"/>
+        <translation>JSON (*.json);;Todos os ficheiros (*)</translation>
     </message>
     <message>
         <location filename="../../assets/UI/mainwindow.ui" line="97"/>
         <source>Export Profile</source>
+        <translation>Exportar o perfil</translation>
+    </message>
+    <message>
+        <location filename="../../views/main_window.py" line="223"/>
+        <source>Failed to import profile</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -1551,32 +1548,32 @@
 <context>
     <name>TrayMenu</name>
     <message>
-        <location filename="../../tray_menu.py" line="45"/>
+        <location filename="../../tray_menu.py" line="43"/>
         <source>Vorta for Borg Backup</source>
         <translation>Vorta para Borg Backup</translation>
     </message>
     <message>
-        <location filename="../../tray_menu.py" line="54"/>
+        <location filename="../../tray_menu.py" line="52"/>
         <source>Backup in Progress</source>
         <translation>Copia de seguridade en curso</translation>
     </message>
     <message>
-        <location filename="../../tray_menu.py" line="55"/>
+        <location filename="../../tray_menu.py" line="53"/>
         <source>Cancel Backup</source>
         <translation>Cancelar a copia de seguridade</translation>
     </message>
     <message>
-        <location filename="../../tray_menu.py" line="58"/>
+        <location filename="../../tray_menu.py" line="56"/>
         <source>Next Task: %s</source>
         <translation>Próxima tarefa: %s</translation>
     </message>
     <message>
-        <location filename="../../tray_menu.py" line="67"/>
+        <location filename="../../tray_menu.py" line="65"/>
         <source>Backup Now</source>
         <translation>Facer unha copia de seguridade agora</translation>
     </message>
     <message>
-        <location filename="../../tray_menu.py" line="72"/>
+        <location filename="../../tray_menu.py" line="70"/>
         <source>Quit</source>
         <translation>Saír</translation>
     </message>
@@ -1644,13 +1641,28 @@
         <translation>Sen isto, algúns ficheiros non serán accesíbeis e pode acabar cunha copia de seguridade incompleta. Estabeleza o permiso de &lt;b&gt;Acceso total ao disco&lt;/b&gt; para Vorta en &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;Preferencias do sistema &gt; Seguridade e privacidade&lt;/a&gt;.</translation>
     </message>
     <message>
-        <location filename="../../application.py" line="264"/>
+        <location filename="../../application.py" line="278"/>
         <source>Profile import successful!</source>
+        <translation>A importación do perfil foi satisfactoria.</translation>
+    </message>
+    <message>
+        <location filename="../../application.py" line="278"/>
+        <source>Profile {} imported.</source>
+        <translation>O perfil {} foi importado.</translation>
+    </message>
+    <message>
+        <location filename="../../application.py" line="265"/>
+        <source>Failed to import profile</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../../application.py" line="264"/>
-        <source>Profile {} imported.</source>
+        <location filename="../../application.py" line="265"/>
+        <source>Failed to import a profile from {}:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../application.py" line="265"/>
+        <source>Consider removing or repairing this file to get rid of this message.</source>
         <translation type="unfinished"/>
     </message>
 </context>
