@@ -95,7 +95,7 @@
     <message>
         <location filename="../../assets/UI/repoadd.ui" line="103"/>
         <source>...</source>
-        <translation>...</translation>
+        <translation>…</translation>
     </message>
     <message>
         <location filename="../../assets/UI/repoadd.ui" line="201"/>
@@ -253,7 +253,7 @@
     <message>
         <location filename="../../views/archive_tab.py" line="361"/>
         <source>Unmounting failed. Make sure no programs are using {}</source>
-        <translation>Het afkoppelen is mislukt. Zorg er voor dat er geen programma&apos;s gebruikmaken van {}</translation>
+        <translation>Het afkoppelen is mislukt. Zorg er voor dat er ‘{}‘ niet in gebruik is door andere programma&apos;s.</translation>
     </message>
     <message>
         <location filename="../../views/archive_tab.py" line="117"/>
@@ -296,7 +296,7 @@
     <message>
         <location filename="../../borg/break_lock.py" line="8"/>
         <source>Breaking repository lock...</source>
-        <translation>Bezig met openbreken van reposlot...</translation>
+        <translation>Bezig met openbreken van reposlot…</translation>
     </message>
     <message>
         <location filename="../../borg/break_lock.py" line="12"/>
@@ -309,7 +309,7 @@
     <message>
         <location filename="../../borg/check.py" line="8"/>
         <source>Starting consistency check...</source>
-        <translation>Bezig met starten van integriteitscontrole...</translation>
+        <translation>Bezig met starten van integriteitscontrole…</translation>
     </message>
     <message>
         <location filename="../../borg/check.py" line="13"/>
@@ -340,7 +340,7 @@
     <message>
         <location filename="../../borg/delete.py" line="8"/>
         <source>Deleting archive...</source>
-        <translation>Bezig met verwijderen...</translation>
+        <translation>Bezig met verwijderen…</translation>
     </message>
     <message>
         <location filename="../../borg/delete.py" line="13"/>
@@ -353,7 +353,7 @@
     <message>
         <location filename="../../borg/diff.py" line="9"/>
         <source>Requesting differences between archives...</source>
-        <translation>Bezig met opvragen van verschillen tussen archieven...</translation>
+        <translation>Bezig met opvragen van verschillen tussen archieven…</translation>
     </message>
     <message>
         <location filename="../../borg/diff.py" line="13"/>
@@ -366,7 +366,7 @@
     <message>
         <location filename="../../borg/extract.py" line="8"/>
         <source>Downloading files from archive...</source>
-        <translation>Bezig met downloaden van bestanden uit archief...</translation>
+        <translation>Bezig met downloaden van bestanden uit archief…</translation>
     </message>
     <message>
         <location filename="../../borg/extract.py" line="13"/>
@@ -379,7 +379,7 @@
     <message>
         <location filename="../../borg/info_archive.py" line="9"/>
         <source>Refreshing archive...</source>
-        <translation>Bezig met verversen van archieven...</translation>
+        <translation>Bezig met verversen van archieven…</translation>
     </message>
     <message>
         <location filename="../../borg/info_archive.py" line="14"/>
@@ -392,7 +392,7 @@
     <message>
         <location filename="../../borg/info_repo.py" line="9"/>
         <source>Validating existing repo...</source>
-        <translation>Bezig met valideren van bestaande repo...</translation>
+        <translation>Bezig met valideren van bestaande repo…</translation>
     </message>
 </context>
 <context>
@@ -400,7 +400,7 @@
     <message>
         <location filename="../../borg/init.py" line="8"/>
         <source>Setting up new repo...</source>
-        <translation>Bezig met instellen van nieuwe repo...</translation>
+        <translation>Bezig met instellen van nieuwe repo…</translation>
     </message>
 </context>
 <context>
@@ -408,7 +408,7 @@
     <message>
         <location filename="../../borg/list_archive.py" line="8"/>
         <source>Getting archive content...</source>
-        <translation>Bezig met ophalen van archiefinhoud...</translation>
+        <translation>Bezig met ophalen van archiefinhoud…</translation>
     </message>
     <message>
         <location filename="../../borg/list_archive.py" line="12"/>
@@ -421,7 +421,7 @@
     <message>
         <location filename="../../borg/list_repo.py" line="10"/>
         <source>Refreshing archives...</source>
-        <translation>Bezig met verversen van archieven...</translation>
+        <translation>Bezig met verversen van archieven…</translation>
     </message>
     <message>
         <location filename="../../borg/list_repo.py" line="15"/>
@@ -434,7 +434,7 @@
     <message>
         <location filename="../../borg/mount.py" line="9"/>
         <source>Mounting archive into folder...</source>
-        <translation>Bezig met aankoppelen van archief in map...</translation>
+        <translation>Bezig met aankoppelen van archief in map…</translation>
     </message>
 </context>
 <context>
@@ -442,7 +442,7 @@
     <message>
         <location filename="../../borg/prune.py" line="9"/>
         <source>Pruning old archives...</source>
-        <translation>Bezig met vernietigen van oude archieven...</translation>
+        <translation>Bezig met vernietigen van oude archieven…</translation>
     </message>
     <message>
         <location filename="../../borg/prune.py" line="14"/>
@@ -483,7 +483,7 @@
     <message>
         <location filename="../../borg/umount.py" line="10"/>
         <source>Unmounting archive...</source>
-        <translation>Bezig met ontkoppelen...</translation>
+        <translation>Bezig met ontkoppelen…</translation>
     </message>
 </context>
 <context>
@@ -526,7 +526,7 @@
     <message>
         <location filename="../../assets/UI/profileadd.ui" line="56"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Backup profiles allow for granular backups from different sources to different destinations. You could e.g. back up essential documents to a remote repository via Wifi, while doing a full backup onto a local storage device.&lt;/p&gt;&lt;p&gt;Repositories and SSH keys are shared between profiles. Source folders, active destination repo, allowed networks, pruning, validation and scheduling are per-profile.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Met back-upprofielen kun je back-ups van verschillende bronnen maken naar verschillende bestemmingen, zoals bijv. belangrijke documenten naar een externe repo via wifi en tegelijkertijd een volledige back-up op een lokaal opslagapparaat.&lt;/p&gt;&lt;p&gt;Repo&apos;s en ssh-sleutels worden gedeeld tussen profielen. Bronmappen, actieve bestemmingsrepo, toegestane netwerken, vernietigen, validatie en tijdschema&apos;s werken per profiel.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Met back-upprofielen kun je back-ups van verschillende bronnen maken naar verschillende bestemmingen, zoals belangrijke documenten naar een externe repo via wifi en tegelijkertijd een volledige back-up op een lokaal opslagapparaat.&lt;/p&gt;&lt;p&gt;Repo&apos;s en ssh-sleutels worden gedeeld tussen profielen. Bronmappen, actieve bestemmingsrepo, toegestane netwerken, vernietigen, validatie en tijdschema&apos;s werken per profiel.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../../assets/UI/profileadd.ui" line="84"/>
@@ -636,27 +636,27 @@
     <message>
         <location filename="../../assets/UI/exportwindow.ui" line="23"/>
         <source>If set, sharing this file with others will disclose your borg passphrase. Use with caution!</source>
-        <translation type="unfinished"/>
+        <translation>Als je dit inschakelt, dan wordt je toegangszin gedeeld tijdens het delen. Wees voorzichtig hiermee!</translation>
     </message>
     <message>
         <location filename="../../assets/UI/exportwindow.ui" line="26"/>
         <source>Include borg passphrase in export</source>
-        <translation type="unfinished"/>
+        <translation>Borg-toegangszin delen tijdens exporteren</translation>
     </message>
     <message>
         <location filename="../../assets/UI/importwindow.ui" line="25"/>
         <source>Borg passphrase:</source>
-        <translation type="unfinished"/>
+        <translation>Borg-toegangszin:</translation>
     </message>
     <message>
         <location filename="../../assets/UI/importwindow.ui" line="53"/>
         <source>Overwrite existing profile</source>
-        <translation type="unfinished"/>
+        <translation>Bestaand profiel overschrijven</translation>
     </message>
     <message>
         <location filename="../../assets/UI/importwindow.ui" line="60"/>
         <source>Overwrite existing settings</source>
-        <translation type="unfinished"/>
+        <translation>Bestaande instellingen overschrijven</translation>
     </message>
 </context>
 <context>
@@ -690,37 +690,37 @@
     <message>
         <location filename="../../views/export_window.py" line="29"/>
         <source>Export Profile</source>
-        <translation type="unfinished"/>
+        <translation>Profiel exporteren</translation>
     </message>
     <message>
         <location filename="../../views/export_window.py" line="38"/>
         <source>The current profile_export has no password</source>
-        <translation type="unfinished"/>
+        <translation>De huidige export is niet voorzien van een wachtwoord</translation>
     </message>
     <message>
         <location filename="../../views/export_window.py" line="43"/>
         <source>Save profile_export</source>
-        <translation type="unfinished"/>
+        <translation>Export opslaan</translation>
     </message>
     <message>
         <location filename="../../views/export_window.py" line="55"/>
         <source>Error while exporting</source>
-        <translation type="unfinished"/>
+        <translation>Fout tijdens exporteren</translation>
     </message>
     <message>
         <location filename="../../views/export_window.py" line="71"/>
         <source>The file {} could not be created. Please choose another location.</source>
-        <translation type="unfinished"/>
+        <translation>‘{}’ kan niet worden aangemaakt - kies een andere locatie.</translation>
     </message>
     <message>
         <location filename="../../views/export_window.py" line="78"/>
         <source>Profile export successful!</source>
-        <translation type="unfinished"/>
+        <translation>Het exporteren is voltooid!</translation>
     </message>
     <message>
         <location filename="../../views/export_window.py" line="78"/>
         <source>Profile export written to {}.</source>
-        <translation type="unfinished"/>
+        <translation>De export is opgeslagen in {}.</translation>
     </message>
 </context>
 <context>
@@ -1191,55 +1191,58 @@
     <message>
         <location filename="../../views/import_window.py" line="24"/>
         <source>Import Profile</source>
-        <translation type="unfinished"/>
+        <translation>Profiel importeren</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="32"/>
         <source>The passphrase has been loaded from the export file</source>
-        <translation type="unfinished"/>
+        <translation>De toegangszin is geladen uit het exportbestand</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="39"/>
         <source>The passphrase has been loaded from your keyring</source>
-        <translation type="unfinished"/>
+        <translation>De toegangszin is geladen uit je sleutelbos</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="49"/>
         <source>A profile with the name {} does not exist. Nothing to overwrite.</source>
-        <translation type="unfinished"/>
+        <translation>Er bestaat geen profiel met de naam ‘{}’ - er kan dus niks worden overschreven.</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="60"/>
         <source>Error while importing</source>
-        <translation type="unfinished"/>
+        <translation>Fout tijdens importeren</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="76"/>
         <source>Schema upgrade failure, file a bug report with the link in the Misc tab with the following error: 
  {0} 
  {1}</source>
-        <translation type="unfinished"/>
+        <translation>Het schema kan niet worden bijgewerkt. Stel een bugmelding op via de link op het tabblad ‘Overig’. Stuur de volgende informatie mee:
+
+ {0}
+ {1}</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="79"/>
         <source>Newer profile_export export files cannot be used on older versions.</source>
-        <translation type="unfinished"/>
+        <translation>Nieuwe exportbestanden kunnen niet worden gebruikt in oudere versies.</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="81"/>
         <source>Cannot read profile_export export file due to permission error.</source>
-        <translation type="unfinished"/>
+        <translation>Het exportbestand kan niet worden uitgelezen wegens een toegangsfout.</translation>
     </message>
     <message>
         <location filename="../../views/import_window.py" line="83"/>
         <source>Profile export file not found.</source>
-        <translation type="unfinished"/>
+        <translation>Het exportbestand is niet aangetroffen.</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../../views/main_window.py" line="255"/>
+        <location filename="../../views/main_window.py" line="256"/>
         <source>Task cancelled</source>
         <translation>Taak afgebroken</translation>
     </message>
@@ -1316,7 +1319,7 @@
     <message>
         <location filename="../../views/main_window.py" line="165"/>
         <source>Are you sure you want to delete profile &apos;{}&apos;?</source>
-        <translation>Weet je zeker dat je &apos;{}&apos; wilt verwijderen?</translation>
+        <translation>Weet je zeker dat je ‘{}’ wilt verwijderen?</translation>
     </message>
     <message>
         <location filename="../../views/main_window.py" line="166"/>
@@ -1324,63 +1327,58 @@
         <translation>Verwijderen bevestigen</translation>
     </message>
     <message>
-        <location filename="../../views/main_window.py" line="272"/>
+        <location filename="../../views/main_window.py" line="273"/>
         <source>Should Vorta continue to run in the background?</source>
         <translation>Wil je dat Vorta blijft draaien op de achtergrond?</translation>
     </message>
     <message>
-        <location filename="../../views/main_window.py" line="277"/>
+        <location filename="../../views/main_window.py" line="278"/>
         <source>Quit</source>
         <translation>Afsluiten</translation>
     </message>
     <message>
-        <location filename="../../views/main_window.py" line="278"/>
+        <location filename="../../views/main_window.py" line="279"/>
         <source>Don&apos;t show this again</source>
         <translation>Niet meer tonen</translation>
     </message>
     <message>
         <location filename="../../views/main_window.py" line="84"/>
         <source>Import from file...</source>
-        <translation type="unfinished"/>
+        <translation>Importeren uit bestand…</translation>
     </message>
     <message>
         <location filename="../../views/main_window.py" line="177"/>
         <source>Can&apos;t delete the last profile.</source>
-        <translation type="unfinished"/>
+        <translation>Het laatste profiel kan niet worden verwijderd.</translation>
     </message>
     <message>
         <location filename="../../views/main_window.py" line="205"/>
         <source>Profile import successful!</source>
-        <translation type="unfinished"/>
+        <translation>Het importeren is voltooid!</translation>
     </message>
     <message>
         <location filename="../../views/main_window.py" line="205"/>
         <source>Profile {} imported.</source>
-        <translation type="unfinished"/>
+        <translation>‘{}’ is geïmporteerd.</translation>
     </message>
     <message>
         <location filename="../../views/main_window.py" line="214"/>
         <source>Load profile</source>
-        <translation type="unfinished"/>
+        <translation>Profiel laden</translation>
     </message>
     <message>
         <location filename="../../views/main_window.py" line="214"/>
         <source>JSON (*.json);;All files (*)</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../../views/main_window.py" line="222"/>
-        <source>Error</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../../views/main_window.py" line="222"/>
-        <source>This file does not contain valid JSON.</source>
-        <translation type="unfinished"/>
+        <translation>JSON (*.json);;Alle bestanden (*)</translation>
     </message>
     <message>
         <location filename="../../assets/UI/mainwindow.ui" line="97"/>
         <source>Export Profile</source>
+        <translation>Profiel exporteren</translation>
+    </message>
+    <message>
+        <location filename="../../views/main_window.py" line="223"/>
+        <source>Failed to import profile</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -1540,7 +1538,7 @@
     <message>
         <location filename="../../views/source_tab.py" line="102"/>
         <source>Calculating...</source>
-        <translation>Bezig met berekenen...</translation>
+        <translation>Bezig met berekenen…</translation>
     </message>
     <message>
         <location filename="../../views/source_tab.py" line="162"/>
@@ -1551,32 +1549,32 @@
 <context>
     <name>TrayMenu</name>
     <message>
-        <location filename="../../tray_menu.py" line="45"/>
+        <location filename="../../tray_menu.py" line="43"/>
         <source>Vorta for Borg Backup</source>
         <translation>Vorta voor Borg Backup</translation>
     </message>
     <message>
-        <location filename="../../tray_menu.py" line="54"/>
+        <location filename="../../tray_menu.py" line="52"/>
         <source>Backup in Progress</source>
         <translation>Er wordt een back-up gemaakt</translation>
     </message>
     <message>
-        <location filename="../../tray_menu.py" line="55"/>
+        <location filename="../../tray_menu.py" line="53"/>
         <source>Cancel Backup</source>
         <translation>Back-uppen afbreken</translation>
     </message>
     <message>
-        <location filename="../../tray_menu.py" line="58"/>
+        <location filename="../../tray_menu.py" line="56"/>
         <source>Next Task: %s</source>
         <translation>Volgende taak: %s</translation>
     </message>
     <message>
-        <location filename="../../tray_menu.py" line="67"/>
+        <location filename="../../tray_menu.py" line="65"/>
         <source>Backup Now</source>
         <translation>Nu back-uppen</translation>
     </message>
     <message>
-        <location filename="../../tray_menu.py" line="72"/>
+        <location filename="../../tray_menu.py" line="70"/>
         <source>Quit</source>
         <translation>Afsluiten</translation>
     </message>
@@ -1626,7 +1624,7 @@
     <message>
         <location filename="../../application.py" line="238"/>
         <source>You do not have permission to access the repository at {repo_url}. Gain access and try again.</source>
-        <translation>Je hebt geen toegang tot de repo &apos;{repo_url}&apos;. Verkrijg toegang en probeer het opnieuw.</translation>
+        <translation>Je hebt geen toegang tot de repo ‘{repo_url}’. Verkrijg toegang en probeer het opnieuw.</translation>
     </message>
     <message>
         <location filename="../../application.py" line="241"/>
@@ -1641,16 +1639,31 @@
     <message>
         <location filename="../../application.py" line="206"/>
         <source>Without this, some files won&apos;t be accessible and you may end up with an incomplete backup. Please set &lt;b&gt;Full Disk Access&lt;/b&gt; permission for Vorta in &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;System Preferences &gt; Security &amp; Privacy&lt;/a&gt;.</source>
-        <translation>Zonder deze toegang zijn sommige bestanden ontoegankelijk en kan leiden tot een onvolledige back-up. Verleen het recht &lt;b&gt;Volledige schijftoegang&lt;/b&gt; permission via &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;Systeemvoorkeuren &gt; Beveiliging en privacy&lt;/a&gt;.</translation>
+        <translation>Zonder deze toegang zijn sommige bestanden ontoegankelijk, wat kan leiden tot een onvolledige back-up. Verleen de bevoegdheid &lt;b&gt;Volledige schijftoegang&lt;/b&gt;  via &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;Systeemvoorkeuren &gt; Beveiliging en privacy&lt;/a&gt;.</translation>
     </message>
     <message>
-        <location filename="../../application.py" line="264"/>
+        <location filename="../../application.py" line="278"/>
         <source>Profile import successful!</source>
+        <translation>Het importeren is voltooid!</translation>
+    </message>
+    <message>
+        <location filename="../../application.py" line="278"/>
+        <source>Profile {} imported.</source>
+        <translation>‘{}’ is geïmporteerd.</translation>
+    </message>
+    <message>
+        <location filename="../../application.py" line="265"/>
+        <source>Failed to import profile</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../../application.py" line="264"/>
-        <source>Profile {} imported.</source>
+        <location filename="../../application.py" line="265"/>
+        <source>Failed to import a profile from {}:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../application.py" line="265"/>
+        <source>Consider removing or repairing this file to get rid of this message.</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -1739,7 +1752,7 @@ https://github.com/borgbase/vorta/issues/new
     <message>
         <location filename="../../borg/create.py" line="165"/>
         <source>Starting backup...</source>
-        <translation>Bezig met starten van back-up...</translation>
+        <translation>Bezig met starten van back-up…</translation>
     </message>
     <message>
         <location filename="../../borg/umount.py" line="27"/>
@@ -1776,7 +1789,7 @@ Herkoppel je repo.</translation>
     <message>
         <location filename="../../borg/borg_thread.py" line="139"/>
         <source>Please unlock your system password manager or disable it under Misc</source>
-        <translation>Ontgrendel je wachtwoordbeheerder of schakel deze optie uit in &apos;Overig&apos;.</translation>
+        <translation>Ontgrendel je wachtwoordbeheerder of schakel deze optie uit op het tabblad ‘Overig’.</translation>
     </message>
 </context>
 <context>
