@@ -1,11 +1,12 @@
 import os
+
 from PyQt5 import uic, QtCore
 from PyQt5.QtWidgets import QApplication, QMessageBox
 
 from vorta.models import RepoModel, ArchiveModel, BackupProfileMixin
 from vorta.utils import pretty_bytes, get_private_keys, get_asset, borg_compat
-from .ssh_dialog import SSHAddWindow
 from .repo_add_dialog import AddRepoWindow, ExistingRepoWindow
+from .ssh_dialog import SSHAddWindow
 from .utils import get_colored_icon
 
 uifile = get_asset('UI/repotab.ui')
@@ -25,8 +26,7 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
         self.repoSelector.addItem(self.tr('+ Initialize New Repository'), 'new')
         self.repoSelector.addItem(self.tr('+ Add Existing Repository'), 'existing')
         self.repoSelector.insertSeparator(3)
-        self.set_repos()
-        self.repoSelector.currentIndexChanged.connect(self.repo_select_action)
+        self.populate_repositories()
         self.repoRemoveToolbutton.clicked.connect(self.repo_unlink_action)
         self.copyURLbutton.clicked.connect(self.copy_URL_action)
 
@@ -66,11 +66,20 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
 
     def set_repos(self):
         count = self.repoSelector.count()
-        for x in range(4, count):  # Repositories are listed after 4th entry in repoSelector
+        for _ in range(4, count):  # Repositories are listed after 4th entry in repoSelector
             self.repoSelector.removeItem(4)
         for repo in RepoModel.select():
             self.repoSelector.addItem(repo.url, repo.id)
 
+    def populate_repositories(self):
+        try:
+            self.repoSelector.currentIndexChanged.disconnect(self.repo_select_action)
+        except TypeError:  # raised when signal is not connected
+            pass
+        self.set_repos()
+        self.populate_from_profile()
+        self.repoSelector.currentIndexChanged.connect(self.repo_select_action)
+
     def populate_from_profile(self):
         profile = self.profile()
         if profile.repo:
@@ -113,12 +122,11 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
     def ssh_select_action(self, index):
         if index == 1:
             ssh_add_window = SSHAddWindow()
+            self._window = ssh_add_window  # For tests
             ssh_add_window.setParent(self, QtCore.Qt.Sheet)
             ssh_add_window.show()
-            if ssh_add_window.exec_():
-                self.init_ssh()
-            else:
-                self.sshComboBox.setCurrentIndex(0)
+            ssh_add_window.accepted.connect(self.init_ssh)
+            ssh_add_window.rejected.connect(lambda: self.sshComboBox.setCurrentIndex(0))
         else:
             profile = self.profile()
             profile.ssh_key = self.sshComboBox.itemData(index)
@@ -138,8 +146,8 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
                 clipboard = QApplication.clipboard()
                 clipboard.setText(pub_key)
 
-                msg.setText(self.tr("Public Key Copied to Clipboard"))
-                msg.setInformativeText(self.tr(
+                msg.setWindowTitle(self.tr("Public Key Copied to Clipboard"))
+                msg.setText(self.tr(
                     "The selected public SSH key was copied to the clipboard. "
                     "Use it to set up remote repo permissions."))
 
@@ -147,7 +155,7 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
                 msg.setText(self.tr("Couldn't find public key."))
         else:
             msg.setText(self.tr("Select a public key from the dropdown first."))
-        msg.exec_()
+        msg.show()
 
     def compression_select_action(self, index):
         profile = self.profile()
@@ -163,12 +171,11 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
                 window = AddRepoWindow()
             else:
                 window = ExistingRepoWindow()
+            self._window = window  # For tests
             window.setParent(self, QtCore.Qt.Sheet)
             window.show()
-            if window.exec_():
-                self.process_new_repo(window.result)
-            else:
-                self.repoSelector.setCurrentIndex(0)
+            window.added_repo.connect(self.process_new_repo)
+            window.rejected.connect(lambda: self.repoSelector.setCurrentIndex(0))
         else:
             profile = self.profile()
             profile.repo = self.repoSelector.currentData()
@@ -203,9 +210,9 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
             repo.delete_instance(recursive=True)  # This also deletes archives.
             self.repoSelector.setCurrentIndex(0)
             self.repoSelector.removeItem(selected_repo_index)
-            msg.setText(self.tr('Repository was Unlinked'))
-            msg.setInformativeText(self.tr('You can always connect it again later.'))
-            msg.exec_()
+            msg.setWindowTitle(self.tr('Repository was Unlinked'))
+            msg.setText(self.tr('You can always connect it again later.'))
+            msg.show()
 
             self.repo_changed.emit()
             self.init_repo_stats()
@@ -214,3 +221,9 @@ class RepoTab(RepoBase, RepoUI, BackupProfileMixin):
         if self.repoSelector.currentIndex() > 2:
             URL = self.repoSelector.currentText()
             QApplication.clipboard().setText(URL)
+        else:
+            msg = QMessageBox()
+            msg.setStandardButtons(QMessageBox.Ok)
+            msg.setParent(self, QtCore.Qt.Sheet)
+            msg.setText(self.tr("Select a repository from the dropdown first."))
+            msg.show()
